Roadmap
*******

This page gives a medium- and long-term overview of future development of :mod:`transport_data`, focused on the tools in this package, but with relevant details about the broader TDC and TDCI.
See also:

- GitHub project `transport-data/projects/1 <https://github.com/orgs/transport-data/projects/1>`_ for general TDCI development.
- GitHub project `transport-data/projects/3 <https://github.com/orgs/transport-data/projects/3>`_ for deployment of CKAN (2024).
